==> aws-cdk.aws-appmesh-1.109.0.tar.gz: package/lib/tls-certificate.d.ts <==
import * as acm from '@aws-cdk/aws-certificatemanager';
import { CfnVirtualNode } from './appmesh.generated';
import { Construct } from '@aws-cdk/core';
/**
 * (experimental) A wrapper for the tls config returned by {@link TlsCertificate.bind}.
 *
 * @experimental
 */
export interface TlsCertificateConfig {
    /**
     * (experimental) The CFN shape for a TLS certificate.
     *
     * @experimental
     */
    readonly tlsCertificate: CfnVirtualNode.ListenerTlsCertificateProperty;
}
/**
 * (experimental) ACM Certificate Properties.
 *
 * @experimental
 */
export interface AcmCertificateOptions {
    /**
     * (experimental) The ACM certificate.
     *
     * @experimental
     */
    readonly certificate: acm.ICertificate;
}
/**
 * (experimental) File Certificate Properties.
 *
 * @experimental
 */
export interface FileCertificateOptions {
    /**
     * (experimental) The file path of the certificate chain file.
     *
     * @experimental
     */
    readonly certificateChainPath: string;
    /**
     * (experimental) The file path of the private key file.
     *
     * @experimental
     */
    readonly privateKeyPath: string;
}
/**
 * (experimental) Represents a TLS certificate.
 *
 * @experimental
 */
export declare abstract class TlsCertificate {
    /**
     * (experimental) Returns an File TLS Certificate.
     *
     * @experimental
     */
    static file(props: FileCertificateOptions): TlsCertificate;
    /**
     * (experimental) Returns an ACM TLS Certificate.
     *
     * @experimental
     */
    static acm(props: AcmCertificateOptions): TlsCertificate;
    /**
     * (experimental) Returns TLS certificate based provider.
     *
     * @experimental
     */
    abstract bind(_scope: Construct): TlsCertificateConfig;
}

==> aws-cdk.aws-appmesh-1.110.0.tar.gz: package/lib/tls-certificate.d.ts <==
import * as acm from '@aws-cdk/aws-certificatemanager';
import { CfnVirtualNode } from './appmesh.generated';
import { Construct } from '@aws-cdk/core';
/**
 * (experimental) A wrapper for the tls config returned by {@link TlsCertificate.bind}.
 *
 * @experimental
 */
export interface TlsCertificateConfig {
    /**
     * (experimental) The CFN shape for a TLS certificate.
     *
     * @experimental
     */
    readonly tlsCertificate: CfnVirtualNode.ListenerTlsCertificateProperty;
}
/**
 * (experimental) Represents a TLS certificate.
 *
 * @experimental
 */
export declare abstract class TlsCertificate {
    /**
     * (experimental) Returns an File TLS Certificate.
     *
     * @experimental
     */
    static file(certificateChainPath: string, privateKeyPath: string): MutualTlsCertificate;
    /**
     * (experimental) Returns an ACM TLS Certificate.
     *
     * @experimental
     */
    static acm(certificate: acm.ICertificate): TlsCertificate;
    /**
     * (experimental) Returns an SDS TLS Certificate.
     *
     * @experimental
     */
    static sds(secretName: string): MutualTlsCertificate;
    /**
     * (experimental) Returns TLS certificate based provider.
     *
     * @experimental
     */
    abstract bind(_scope: Construct): TlsCertificateConfig;
}
/**
 * (experimental) Represents a TLS certificate that is supported for mutual TLS authentication.
 *
 * @experimental
 */
export declare abstract class MutualTlsCertificate extends TlsCertificate {
    /**
     * @experimental
     */
    protected readonly differentiator = false;
}
